==> ace_5.4.2.1.0.orig.tar.gz: ACE_wrappers/TAO/tests/Exposed_Policies/Policy_Verifier.h <==
// Policy_Verifier.h,v 1.8 2003/10/28 18:30:47 bala Exp
//
// ============================================================================
//
// = LIBRARY
//    TAO/tests/Exposed_Policies
//
// = FILENAME
//    Policy_Verifier.h
//
// = DESCRIPTION
//     This class verifies that the policy are correctly embedded
//     in the IOR.
//
// = AUTHOR
//     Angelo Corsaro <corsaro@cs.wustl.edu>
//
// ============================================================================

#ifndef POLICY_VERIFIER_H_
#define POLICY_VERIFIER_H_

// -- App. Specific Include --
#include "CounterC.h"
#include "RT_Properties.h"

// -- ACE Include --
#include "ace/Arg_Shifter.h"
#include "ace/Log_Msg.h"

// -- TAO Include --
#include "tao/Basic_Types.h"
#include "tao/ORB_Constants.h"

class Policy_Verifier
{
public:

  // -- Ctor/Dtor --
  Policy_Verifier (void);
  ~Policy_Verifier (void);

  void init (int argc,
             char *argv[]
             ACE_ENV_ARG_DECL_WITH_DEFAULTS);

  void run (ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS);

private:
  // -- Helper methods --
  void verify_reference (Counter_ptr counter,
                         RT_Properties *rt_properties
                         ACE_ENV_ARG_DECL_WITH_DEFAULTS);

  CORBA::Boolean check_reference (CORBA::Object_ptr object,
                                  const char *msg);

private:

  CORBA::ORB_var orb_;

  RT_Properties *rt_object_properties_;
  RT_Properties *rt_poa_properties_;
  unsigned int priority_bands_;
  Counter_var base_object_;
  Counter_var overridden_object_;

  char base_object_ref_[256];
  char overridden_object_ref_[256];
};

#endif /* POLICY_VERIFIER_H_ */

==> ace_5.4.7.orig.tar.gz: ACE_wrappers/TAO/tests/Exposed_Policies/Policy_Verifier.h <==
// Policy_Verifier.h,v 1.9 2005/06/27 16:10:03 elliott_c Exp
//
// ============================================================================
//
// = LIBRARY
//    TAO/tests/Exposed_Policies
//
// = FILENAME
//    Policy_Verifier.h
//
// = DESCRIPTION
//     This class verifies that the policy are correctly embedded
//     in the IOR.
//
// = AUTHOR
//     Angelo Corsaro <corsaro@cs.wustl.edu>
//
// ============================================================================

#ifndef POLICY_VERIFIER_H_
#define POLICY_VERIFIER_H_

// -- App. Specific Include --
#include "CounterC.h"
#include "RT_Properties.h"

// -- ACE Include --
#include "ace/Arg_Shifter.h"
#include "ace/Log_Msg.h"

// -- TAO Include --
#include "tao/Basic_Types.h"
#include "tao/ORB_Constants.h"

class Policy_Verifier
{
public:

  // -- Ctor/Dtor --
  Policy_Verifier (void);
  ~Policy_Verifier (void);

  bool init (int argc,
             char *argv[]
             ACE_ENV_ARG_DECL_WITH_DEFAULTS);

  void run (ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS);

private:
  // -- Helper methods --
  void verify_reference (Counter_ptr counter,
                         RT_Properties *rt_properties
                         ACE_ENV_ARG_DECL_WITH_DEFAULTS);

  CORBA::Boolean check_reference (CORBA::Object_ptr object,
                                  const char *msg);

private:

  CORBA::ORB_var orb_;

  RT_Properties *rt_object_properties_;
  RT_Properties *rt_poa_properties_;
  unsigned int priority_bands_;
  Counter_var base_object_;
  Counter_var overridden_object_;

  char base_object_ref_[256];
  char overridden_object_ref_[256];
};

#endif /* POLICY_VERIFIER_H_ */
